.. TCPB documentation master file, created by
   sphinx-quickstart on Fri Dec 27 12:30:47 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to TCPB's documentation!
================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:
   
   readme
   tcpb


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
